function val = g1(problem,x1,x2)
% This file is part of the OPTPDE problem collection
%                 http://www.optpde.net
% It is provided as is, without any warranty, under the 
%
% Creative Commons Attribution-NonCommercial ShareAlike 4.0 International
%
%         http://creativecommons.org/licenses/by-nc-sa/4.0/
%
% Please give proper credits when using this file by referencing the 
% collection. For this purpose detailed bibliography data is 
% available at the collections website 
%                  
%                 http://www.optpde.net
%
% This file contains data for the benchmark problem 
%                      ccbnd1
% from  2022-04-01 



% remember the size of the input and resize it
[m,n] = size(x1);
x1 = x1(:)';
x2 = x2(:)';

% convert input to polar coordinates with phi in [0,2*pi)
[phi,r] = cart2pol(x1,x2);
phi(phi<0) = phi(phi<0) + 2*pi;

% evaluate the gradient of the desired state yd
lrlm1 = problem.lambda * r .* (problem.lambda-1);
lrl = problem.lambda * r .* problem.lambda;
coslphi = cos(problem.lambda * phi);
sinlphi = sin(problem.lambda * phi);
grad_yd = [-lrlm1 .* coslphi .* x1 ./ r - lrl .* sinlphi .* x2 ./ (r.^2); ...
-lrlm1 .* coslphi .* x2 ./ r + lrl .* sinlphi .* x1 ./ (r.^2)];

% evaluate the normal vector; if (x1,x2) does not belong to the boundary,
% the normal vector will be set to NaN
normal = nan(2,length(x1));
ix1 = find((x2 == 0) & (0 < x1) & (x1 < 1));
ix2 = find((x1 == 1) & (0 < x2) & (x2 < 1));
ix3 = find((x2 == 1) & (-1 < x1) & (x1 < 1));
ix4 = find((x1 == -1) & (-1 < x2) & (x2 < 1));
ix5 = find((x2 == -1) & (-1 < x1) & (x1 < 1));
ix6 = find((x1 == 1) & (-1 < x2) & (x2 < 0));
ix7 = find((abs(phi-problem.omega) <= pi/180) & (0 < r));
ix7 = setdiff(ix7,[ix1,ix2,ix3,ix4,ix5,ix6]);

normal(:,ix1) = repmat([ 0; -1],1,length(ix1));
normal(:,ix2) = repmat([ 1;  0],1,length(ix2));
normal(:,ix3) = repmat([ 0;  1],1,length(ix3));
normal(:,ix4) = repmat([-1;  0],1,length(ix4));
normal(:,ix5) = repmat([ 0; -1],1,length(ix5));
normal(:,ix6) = repmat([ 1;  0],1,length(ix6));
normal(:,ix7) = repmat([sin(problem.omega); -cos(problem.omega)],1,length(ix7));

% evaluate the function g1 = - grad_yd * normal
val = - sum(grad_yd .* normal);

% reshape the output
val = reshape(val,m,n);

