% This file is part of the OPTPDE problem collection
%                 http://www.optpde.net
% It is provided as is, without any warranty, under the 
%
% Creative Commons Attribution-NonCommercial ShareAlike 4.0 International
%
%         http://creativecommons.org/licenses/by-nc-sa/4.0/
%
% Please give proper credits when using this file by referencing the 
% collection. For this purpose detailed bibliography data is 
% available at the collections website 
%                  
%                 http://www.optpde.net
%
% This file contains data for the benchmark problem 
%                      ccbnd1
% from  2022-04-01 


% setup the problem
problem = setup_problem;

% generate a grid which covers the domain
[x1,x2] = meshgrid(linspace(-1,1,81),linspace(-1,1,81));

% find the points inside the domain
inside = inpolygon(x1,x2,problem.vertices(1,:),problem.vertices(2,:));

% transform the grid to the (r,phi) plane
[phi,r] = cart2pol(x1,x2);

% plot the desired state
figure(1); clf; hold on
patch(problem.vertices(1,:),problem.vertices(2,:),'red','FaceAlpha',0.1,'EdgeColor','r');
val = yd(problem,r,phi);
plot3(x1(inside),x2(inside),val(inside),'.');
xlabel('x_1');
ylabel('x_2');
title('desired state y_d');
axis([-1.1 1.1 -1.1 1.1]);

% plot the objective term g1
figure(2); clf; hold on
patch(problem.vertices(1,:),problem.vertices(2,:),'red','FaceAlpha',0.1,'EdgeColor','r');
val = g1(problem,x1,x2);
plot3(x1(inside),x2(inside),val(inside),'.');
xlabel('x_1');
ylabel('x_2');
title('objective term g_1');
view(3);

% plot the objective term g2
figure(3); clf; hold on
patch(problem.vertices(1,:),problem.vertices(2,:),'red','FaceAlpha',0.1,'EdgeColor','r');
val = g2(problem,x1,x2);
plot3(x1(inside),x2(inside),val(inside),'.');
xlabel('x_1');
ylabel('x_2');
title('objective term g_2');
view(3);

